package sgc.portal.ei.ei0104.persistence;

import org.apache.ibatis.annotations.Mapper;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.ei.ei0104.dto.EI01040001USearch;
import sgc.portal.ei.ei0104.model.EI01040001U;

import java.util.List;

@Mapper
public interface EI01040001UMapper {
	
	/*
     * SEARCH LIST
     */
    List<EasyHashMap<String, Object>> getList(EI01040001USearch search);
    
    /*
     * UPDATE
     */
    int update1(EI01040001U eI01040001U);
    
    int update2(EI01040001U eI01040001U);
    
    int update3(EI01040001U eI01040001U);
    
    int update4(EI01040001U eI01040001U);
    
    int update5(EI01040001U eI01040001U);
    
    int update6(EI01040001U eI01040001U);
    
    int update7(EI01040001U eI01040001U);
    
    int update8(EI01040001U eI01040001U);
    
    int update9(EI01040001U eI01040001U);
    
    int update10(EI01040001U eI01040001U);
    
    int update11(EI01040001U eI01040001U);
    
    int update12(EI01040001U eI01040001U);
    
    int update13(EI01040001U eI01040001U);
    
    
    int insertOrUpdate1(EI01040001U eI01040001U);
    
    int insertOrUpdate2(EI01040001U eI01040001U);
    
    int insertOrUpdate3(EI01040001U eI01040001U);
    
    int insertOrUpdate4(EI01040001U eI01040001U);
    
    int insertOrUpdate5(EI01040001U eI01040001U);
    
    int insertOrUpdate6(EI01040001U eI01040001U);
    
    int insertOrUpdate7(EI01040001U eI01040001U);
    
    int insertOrUpdate8(EI01040001U eI01040001U);
    
    int insertOrUpdate9(EI01040001U eI01040001U);
    
    int insertOrUpdate10(EI01040001U eI01040001U);
    
    int insertOrUpdate11(EI01040001U eI01040001U);
    
    int insertOrUpdate12(EI01040001U eI01040001U);
    
    int insertOrUpdate13(EI01040001U eI01040001U);
    
}
